@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/python2
 
 import os
 import sys
@@ -6,7 +6,7 @@ sys.path.insert(0, '.')
 
 import py.path
 
-from pypy.tool.build_cffi_imports import create_cffi_import_libraries
+from lib_pypy.tools.build_cffi_imports import create_cffi_import_libraries
 
 
 class FakeOptions(object):
